@@ -1,8 +1,11 @@
 # -*- coding: utf_8 -*-
 """Pattern Macher."""
-import copy
+from copy import deepcopy
 
-from libsast.core_matcher.helpers import get_rules
+from libsast.core_matcher.helpers import (
+    get_rules,
+    strip_comments,
+)
 from libsast.core_matcher import matchers
 from libsast import (
     common,
@@ -65,11 +68,10 @@ class PatternMatcher:
             for rule in self.scan_rules:
                 case = rule.get('input_case')
                 if case == 'lower':
-                    fmt_data = data.lower()
+                    data = data.lower()
                 elif case == 'upper':
-                    fmt_data = data.upper()
-                else:
-                    fmt_data = data
+                    data = data.upper()
+                fmt_data = strip_comments(data)
                 matches = self.matcher._find_match(
                     rule['type'],
                     fmt_data,
@@ -82,7 +84,7 @@ class PatternMatcher:
     def add_finding(self, file_path, rule, matches):
         """Add Code Analysis Findings."""
         for match in matches:
-            crule = copy.deepcopy(rule)
+            crule = deepcopy(rule)
             file_details = {
                 'file_path': file_path,
                 'match_string': match[0],
