@@ -1,6 +1,5 @@
 # -*- coding: utf_8 -*-
 """The libsast Scanner module."""
-import os
 from pathlib import Path
 
 from libsast.core_matcher.pattern_matcher import (
@@ -65,11 +64,9 @@ class Scanner:
         for path in paths:
             pobj = Path(path)
             if pobj.is_dir():
-                for root, _, files in os.walk(path):
-                    for filename in files:
-                        pfile = Path(os.path.join(root, filename))
-                        if self.validate_file(pfile):
-                            all_files.add(pfile)
+                for pfile in pobj.rglob('*'):
+                    if self.validate_file(pfile):
+                        all_files.add(pfile)
             else:
                 if self.validate_file(pobj):
                     all_files.add(pobj)
